#ifndef __TIMER_H
#define __TIMER_H
#include "sys.h"


//void TIM1_PWM_SetFreq(uint32_t freq,u16 psc);
void TIM1_PWM_CH1_Init(void);
void TIM1_Int_Init(u16 arr,u16 psc);
void TIM1_PWM_Init(u16 arr,u16 psc);
void TIM2_Int_Init(u16 arr,u16 psc);//TIM2为捕获定时器，限位  fan ?  
void TIM3_Int_Init(u16 arr,u16 psc);//TIM3为捕获定时器				Nmbernow,NmberTarget
void TIM5_Int_Init(u16 arr,u16 psc);//TIM4为捕获定时器，限位  loop

void TIM2_Capture_Init(void);				//正限位
void TIM4_Capture_Init(void);				//负限位

void EXTI_Config(void);						//TIM4有误，改为 EXTI

#endif
